Random

Enum Random 

pub enum Random {
    System(System),
    Zero(Zero),
    Xoshiro(Xoshiro),
    ChaCha20(ChaCha20),
}
Randomness source

Applications using Passgen should allow the user to configure the source of randomness by specifying this value. It defaults to using the System randomness generator, which is non-deterministic.

Variants



System(System)



Zero(Zero)



Xoshiro(Xoshiro)



ChaCha20(ChaCha20)

Implementations

Source

impl Random

pub fn from_master_pass(pass: &str, salt: &str) -> Self

When using master pass mode, this method should be used (with the specified master passphrase) to generate the appropriate source of randomness.