pub enum Random {
System(System),
Zero(Zero),
Xoshiro(Xoshiro),
ChaCha20(ChaCha20),
}Expand description
Randomness source
Applications using Passgen should allow the user to configure the source of randomness by specifying this value. It defaults to using the System randomness generator, which is non-deterministic.
Variants
Implementations